Learn R Programming

CAnD (version 1.4.0)

ancestries: Sample Chromosomal Proportions of Ancestral Subpopulations to Use for CAnD Testing

Description

This dataset provides simulated ancestral proportions by chromosomes for 50 samples. The samples are assumed to have three different ancestral proportions, denoted by Euro_, Afr_ and Asian_. Furthermore, these proportions are included as averages across each chromosome 1-22 and the X chromosome.

Usage

ancestries

Arguments

Value

A character value of the name of the dataset.

Format

A data.frame containing 50 rows and 70 columns:
IID
unique sample id
Euro_AA
simulated proportion European ancestry on each chromosome, where AA ranges from 1-22, X
Afr_AA
simulated proportion African ancestry on each chromosome, where AA ranges from 1-22, X